## [0.2.0]

### Modified
- Modified documentation and API to refer to atlas.internationalbrainlab.org (before atlas2)

## [0.1.1]

### Modified
- HOTFIX: Fix for token to be passed in

## [0.1.0]

### Added
 - API and mapping files that were located in the ephys-atlas-web github repository.